@@ -16,7 +16,7 @@ var sshConfigCmd = &cobra.Command{
 	Long:  `Show configuration of the SSH connection to the VM.`,
 	Args:  cobra.MaximumNArgs(1),
 	RunE: func(cmd *cobra.Command, args []string) error {
-		resp, err := limautil.ShowSSH(config.CurrentProfile().ID, sshConfigCmdArgs.layer)
+		resp, err := limautil.ShowSSH(config.CurrentProfile().ID)
 		if err == nil {
 			fmt.Println(resp.Output)
 		}
@@ -24,12 +24,6 @@ var sshConfigCmd = &cobra.Command{
 	},
 }
 
-var sshConfigCmdArgs struct {
-	layer bool
-}
-
 func init() {
 	root.Cmd().AddCommand(sshConfigCmd)
-
-	sshConfigCmd.Flags().BoolVarP(&sshConfigCmdArgs.layer, "layer", "l", true, "config for the Ubuntu layer (if enabled)")
 }
