@@ -6,6 +6,7 @@ import (
 	"github.com/abiosoft/colima/app"
 	"github.com/abiosoft/colima/cmd/root"
 	"github.com/abiosoft/colima/config"
+	"github.com/abiosoft/colima/model"
 	"github.com/abiosoft/colima/store"
 	"github.com/spf13/cobra"
 )
@@ -27,7 +28,7 @@ var versionCmd = &cobra.Command{
 			// Show AI model runner version if provisioned
 			s, _ := store.Load()
 			if s.RamalamaProvisioned {
-				if modelVersion := getRamalamaVersion(); modelVersion != "" {
+				if modelVersion := model.GetRamalamaVersion(); modelVersion != "" {
 					fmt.Println()
 					fmt.Println("AI model runner")
 					fmt.Println("version:", modelVersion)
