@@ -70,3 +70,16 @@ func ContainerRuntimes() (names []string) {
 	}
 	return
 }
+
+// DataDisk holds the configuration for mounting an external runtime disk.
+type DataDisk struct {
+	Dirs     []DiskDir // the directories to be mounted
+	PreMount []string  // the scripts to run before mounting the directories
+	FSType   string    // the filesystem type for the disk e.g. ext4
+}
+
+// DiskDir is a directory mounted in a data disk.
+type DiskDir struct {
+	Name string
+	Path string
+}
