@@ -130,3 +130,23 @@ func (c containerdRuntime) Version(ctx context.Context) string {
 func (c *containerdRuntime) Update(ctx context.Context) (bool, error) {
 	return false, fmt.Errorf("update not supported for the %s runtime", Name)
 }
+
+// DataDirs represents the data disk for the container runtime.
+func DataDisk() environment.DataDisk {
+	return environment.DataDisk{
+		Dirs:   diskDirs,
+		FSType: "ext4",
+		PreMount: []string{
+			"systemctl stop containerd.service",
+			"systemctl stop buildkit.service",
+		},
+	}
+}
+
+var diskDirs = []environment.DiskDir{
+	{Name: "containerd", Path: "/var/lib/containerd"},
+	{Name: "buildkit", Path: "/var/lib/buildkit"},
+	{Name: "nerdctl", Path: "/var/lib/nerdctl"},
+	{Name: "rancher", Path: "/var/lib/rancher"},
+	{Name: "cni", Path: "/var/lib/cni"},
+}
