@@ -33,11 +33,11 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 	if util.MacOS13OrNewer() && conf.VMType == limaconfig.VZ && sameArchitecture {
 		l.VMType = limaconfig.VZ
 
-		// Rosetta is only available on M1
+		// Rosetta is only available on Apple Silicon
 		if conf.VZRosetta && util.MacOS13OrNewerOnArm() {
 			if util.RosettaRunning() {
-				l.Rosetta.Enabled = true
-				l.Rosetta.BinFmt = true
+				l.VMOpts.VZOpts.Rosetta.Enabled = true
+				l.VMOpts.VZOpts.Rosetta.BinFmt = true
 			} else {
 				logrus.Warnln("Unable to enable Rosetta: Rosetta2 is not installed")
 				logrus.Warnln("Run 'softwareupdate --install-rosetta' to install Rosetta2")
@@ -49,6 +49,11 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		}
 	}
 
+	// when krunkit is chosen and OS version supports it
+	if util.MacOS13OrNewerOnArm() && conf.VMType == limaconfig.Krunkit && sameArchitecture {
+		l.VMType = limaconfig.Krunkit
+	}
+
 	if conf.CPUType != "" && conf.CPUType != "host" {
 		l.VMOpts.QEMU.CPUType = map[environment.Arch]string{
 			l.Arch: conf.CPUType,
@@ -137,8 +142,8 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 			if conf.Network.PreferredRoute {
 				metric = limautil.NetMetricPreferred
 			}
-			// vmnet is always used for incus runtime or bridged mode
-			if l.VMType == limaconfig.VZ && conf.Runtime != incus.Name && conf.Network.Mode != "bridged" {
+			// vmnet is used for bridged mode, otherwise VZ uses VZNAT
+			if l.VMType == limaconfig.VZ && conf.Network.Mode != "bridged" {
 				l.Networks = append(l.Networks, limaconfig.Network{
 					VZNAT:     true,
 					Interface: limautil.NetInterface,
@@ -256,6 +261,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 				})
 		}
 
+		// incus socket
 		if conf.Runtime == incus.Name {
 			l.PortForwards = append(l.PortForwards,
 				limaconfig.PortForward{
@@ -265,56 +271,66 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 				})
 		}
 
-		// handle port forwarding to allow listening on 0.0.0.0
-		// bind 0.0.0.0
-		l.PortForwards = append(l.PortForwards,
-			limaconfig.PortForward{
-				GuestIPMustBeZero: true,
-				GuestIP:           net.IPv4zero,
-				GuestPortRange:    [2]int{1, 65535},
-				HostIP:            net.IPv4zero,
-				HostPortRange:     [2]int{1, 65535},
-				Proto:             limaconfig.TCP,
-			},
-			limaconfig.PortForward{
-				GuestIPMustBeZero: true,
-				GuestIP:           net.IPv4zero,
-				GuestPortRange:    [2]int{1, 65535},
-				HostIP:            net.IPv4zero,
-				HostPortRange:     [2]int{1, 65535},
-				Proto:             limaconfig.UDP,
-			},
-		)
-		// bind 127.0.0.1
-		l.PortForwards = append(l.PortForwards,
-			limaconfig.PortForward{
-				GuestIP:        net.ParseIP("127.0.0.1"),
-				GuestPortRange: [2]int{1, 65535},
-				HostIP:         net.ParseIP("127.0.0.1"),
-				HostPortRange:  [2]int{1, 65535},
-				Proto:          limaconfig.TCP,
-			},
-			limaconfig.PortForward{
-				GuestIP:        net.ParseIP("127.0.0.1"),
-				GuestPortRange: [2]int{1, 65535},
-				HostIP:         net.ParseIP("127.0.0.1"),
-				HostPortRange:  [2]int{1, 65535},
-				Proto:          limaconfig.UDP,
-			},
-		)
+		if conf.PortForwarder == "none" {
+			// disable port forwarding
+			l.PortForwards = append(l.PortForwards,
+				limaconfig.PortForward{
+					GuestIP: net.IPv4zero,
+					Proto:   "any",
+					Ignore:  true,
+				})
+		} else {
+			// handle port forwarding to allow listening on 0.0.0.0
+			// bind 0.0.0.0
+			l.PortForwards = append(l.PortForwards,
+				limaconfig.PortForward{
+					GuestIPMustBeZero: true,
+					GuestIP:           net.IPv4zero,
+					GuestPortRange:    [2]int{1, 65535},
+					HostIP:            net.IPv4zero,
+					HostPortRange:     [2]int{1, 65535},
+					Proto:             limaconfig.TCP,
+				},
+				limaconfig.PortForward{
+					GuestIPMustBeZero: true,
+					GuestIP:           net.IPv4zero,
+					GuestPortRange:    [2]int{1, 65535},
+					HostIP:            net.IPv4zero,
+					HostPortRange:     [2]int{1, 65535},
+					Proto:             limaconfig.UDP,
+				},
+			)
+			// bind 127.0.0.1
+			l.PortForwards = append(l.PortForwards,
+				limaconfig.PortForward{
+					GuestIP:        net.ParseIP("127.0.0.1"),
+					GuestPortRange: [2]int{1, 65535},
+					HostIP:         net.ParseIP("127.0.0.1"),
+					HostPortRange:  [2]int{1, 65535},
+					Proto:          limaconfig.TCP,
+				},
+				limaconfig.PortForward{
+					GuestIP:        net.ParseIP("127.0.0.1"),
+					GuestPortRange: [2]int{1, 65535},
+					HostIP:         net.ParseIP("127.0.0.1"),
+					HostPortRange:  [2]int{1, 65535},
+					Proto:          limaconfig.UDP,
+				},
+			)
 
-		// bind all host addresses when network address is not enabled
-		if !conf.Network.Address && conf.Network.HostAddresses {
-			for _, ip := range util.HostIPAddresses() {
-				l.PortForwards = append(l.PortForwards,
-					limaconfig.PortForward{
-						GuestIP:        ip,
-						GuestPortRange: [2]int{1, 65535},
-						HostIP:         ip,
-						HostPortRange:  [2]int{1, 65535},
-						Proto:          limaconfig.TCP,
-					},
-				)
+			// bind all host addresses when network address is not enabled
+			if !conf.Network.Address && conf.Network.HostAddresses {
+				for _, ip := range util.HostIPAddresses() {
+					l.PortForwards = append(l.PortForwards,
+						limaconfig.PortForward{
+							GuestIP:        ip,
+							GuestPortRange: [2]int{1, 65535},
+							HostIP:         ip,
+							HostPortRange:  [2]int{1, 65535},
+							Proto:          limaconfig.TCP,
+						},
+					)
+				}
 			}
 		}
 	}
@@ -357,7 +373,7 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 
 	/* end */
 
-	if len(conf.Mounts) == 0 {
+	if conf.Mounts != nil && len(conf.Mounts) == 0 {
 		l.Mounts = append(l.Mounts,
 			limaconfig.Mount{Location: "~", Writable: true},
 		)
@@ -394,8 +410,11 @@ func newConf(ctx context.Context, conf config.Config) (l limaconfig.Config, err
 		}
 	}
 
-	// provision scripts
+	// provision scripts (only pass Lima-managed modes)
 	for _, script := range conf.Provision {
+		if script.IsColimaMode() {
+			continue
+		}
 		l.Provision = append(l.Provision, limaconfig.Provision{
 			Mode:   script.Mode,
 			Script: script.Script,
