@@ -8,7 +8,7 @@ import (
 )
 
 // WriteTemplate writes template with body to file after applying values.
-func WriteTemplate(body string, file string, values interface{}) error {
+func WriteTemplate(body string, file string, values any) error {
 	b, err := ParseTemplate(body, values)
 	if err != nil {
 		return err
@@ -17,7 +17,7 @@ func WriteTemplate(body string, file string, values interface{}) error {
 }
 
 // ParseTemplate parses template with body and values and returns the resulting bytes.
-func ParseTemplate(body string, values interface{}) ([]byte, error) {
+func ParseTemplate(body string, values any) ([]byte, error) {
 	t, err := template.New("").Parse(body)
 	if err != nil {
 		return nil, fmt.Errorf("error parsing template: %w", err)
